gelman/transform
This module defines functions that perform statistical transformations over a dataset.
A statistical transformation is a function that modifies the dataset based on some statistically desirable qualities.
A statistical function could preserve the size of the dataset or it could reduce the size of the dataset by excluding some elements. Unlike the functions in summarize or discretize, these do not error out if the dataset has no elements.
Values
pub fn winsorize(
dataset: List(Float),
left: Float,
right: Float,
) -> Result(List(Float), error.StatsError)