gelman/discretize
This module defines functions that compute the frequency statistics for a given dataset.
A frequency statistic is a function that takes many data points and returns a few data points that measure the dispersion of frequencies within the dataset.
Each function within this module takes as its first argument a dataset, which is a list of floats.
Every function within this module could potentially produce StatsError. For more information about the what each error represents, please refer to gelman/error
Values
pub fn quantiles(
dataset: List(Float),
qs: List(Float),
) -> Result(List(Float), error.StatsError)